==> gorilla-notes-0.4.0-20200912.222428-2.jar: public/js/compiled/cljs-runtime/module$node_modules$react_grid_layout$build$components$WidthProvider.js <==
import "./cljs_env.js";
shadow$provide.module$node_modules$react_grid_layout$build$components$WidthProvider=function(global,require,module,exports){function _interopRequireDefault(obj){return obj&&obj.__esModule?obj:{default:obj}}function _getRequireWildcardCache(){if("function"!==typeof WeakMap)return null;var cache=new WeakMap;_getRequireWildcardCache=function(){return cache};return cache}function _typeof(obj$jscomp$0){"@babel/helpers - typeof";_typeof="function"===typeof Symbol&&"symbol"===typeof Symbol.iterator?function(obj){return typeof obj}:
function(obj){return obj&&"function"===typeof Symbol&&obj.constructor===Symbol&&obj!==Symbol.prototype?"symbol":typeof obj};return _typeof(obj$jscomp$0)}function _extends(){_extends=Object.assign||function(target){for(var i=1;i<arguments.length;i++){var source=arguments[i],key;for(key in source)Object.prototype.hasOwnProperty.call(source,key)&&(target[key]=source[key])}return target};return _extends.apply(this,arguments)}function _defineProperties(target,props){for(var i=0;i<props.length;i++){var descriptor=
props[i];descriptor.enumerable=descriptor.enumerable||!1;descriptor.configurable=!0;"value"in descriptor&&(descriptor.writable=!0);Object.defineProperty(target,descriptor.key,descriptor)}}function _createClass(Constructor,protoProps,staticProps){protoProps&&_defineProperties(Constructor.prototype,protoProps);staticProps&&_defineProperties(Constructor,staticProps);return Constructor}function _possibleConstructorReturn(self,call){return!call||"object"!==_typeof(call)&&"function"!==typeof call?_assertThisInitialized(self):
call}function _getPrototypeOf(o$jscomp$0){_getPrototypeOf=Object.setPrototypeOf?Object.getPrototypeOf:function(o){return o.__proto__||Object.getPrototypeOf(o)};return _getPrototypeOf(o$jscomp$0)}function _assertThisInitialized(self){if(void 0===self)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return self}function _inherits(subClass,superClass){if("function"!==typeof superClass&&null!==superClass)throw new TypeError("Super expression must either be null or a function");
subClass.prototype=Object.create(superClass&&superClass.prototype,{constructor:{value:subClass,writable:!0,configurable:!0}});superClass&&_setPrototypeOf(subClass,superClass)}function _setPrototypeOf(o$jscomp$0,p$jscomp$0){_setPrototypeOf=Object.setPrototypeOf||function(o,p){o.__proto__=p;return o};return _setPrototypeOf(o$jscomp$0,p$jscomp$0)}function _defineProperty(obj,key,value){key in obj?Object.defineProperty(obj,key,{value,enumerable:!0,configurable:!0,writable:!0}):obj[key]=value;return obj}
Object.defineProperty(exports,"__esModule",{value:!0});exports.default=function(ComposedComponent){var _class,_temp;return _temp=_class=function(_React$Component){function WidthProvider(){var _getPrototypeOf2;if(!(this instanceof WidthProvider))throw new TypeError("Cannot call a class as a function");for(var _len=arguments.length,args=Array(_len),_key=0;_key<_len;_key++)args[_key]=arguments[_key];var _this=_possibleConstructorReturn(this,(_getPrototypeOf2=_getPrototypeOf(WidthProvider)).call.apply(_getPrototypeOf2,
[this].concat(args)));_defineProperty(_assertThisInitialized(_this),"state",{width:1280});_defineProperty(_assertThisInitialized(_this),"mounted",!1);_defineProperty(_assertThisInitialized(_this),"onWindowResize",function(){if(_this.mounted){var node=_reactDom.default.findDOMNode(_assertThisInitialized(_this));node instanceof HTMLElement&&_this.setState({width:node.offsetWidth})}});return _this}_inherits(WidthProvider,_React$Component);_createClass(WidthProvider,[{key:"componentDidMount",value:function(){this.mounted=
!0;window.addEventListener("resize",this.onWindowResize);this.onWindowResize()}},{key:"componentWillUnmount",value:function(){this.mounted=!1;window.removeEventListener("resize",this.onWindowResize)}},{key:"render",value:function(){var _this$props=this.props,measureBeforeMount=_this$props.measureBeforeMount;var excluded=["measureBeforeMount"];if(null==_this$props)_this$props={};else{if(null==_this$props)var target={};else{target={};var sourceKeys=Object.keys(_this$props),i;for(i=0;i<sourceKeys.length;i++){var key=
sourceKeys[i];0<=excluded.indexOf(key)||(target[key]=_this$props[key])}}if(Object.getOwnPropertySymbols)for(i=Object.getOwnPropertySymbols(_this$props),key=0;key<i.length;key++)sourceKeys=i[key],0<=excluded.indexOf(sourceKeys)||Object.prototype.propertyIsEnumerable.call(_this$props,sourceKeys)&&(target[sourceKeys]=_this$props[sourceKeys]);_this$props=target}return measureBeforeMount&&!this.mounted?React.createElement("div",{className:this.props.className,style:this.props.style}):React.createElement(ComposedComponent,
_extends({},_this$props,this.state))}}]);return WidthProvider}(React.Component),_defineProperty(_class,"defaultProps",{measureBeforeMount:!1}),_defineProperty(_class,"propTypes",{measureBeforeMount:_propTypes.default.bool}),_temp};var React=function(obj){if(obj&&obj.__esModule)return obj;if(null===obj||"object"!==_typeof(obj)&&"function"!==typeof obj)return{default:obj};var cache=_getRequireWildcardCache();if(cache&&cache.has(obj))return cache.get(obj);var newObj={},hasPropertyDescriptor=Object.defineProperty&&
Object.getOwnPropertyDescriptor,key;for(key in obj)if(Object.prototype.hasOwnProperty.call(obj,key)){var desc=hasPropertyDescriptor?Object.getOwnPropertyDescriptor(obj,key):null;desc&&(desc.get||desc.set)?Object.defineProperty(newObj,key,desc):newObj[key]=obj[key]}newObj.default=obj;cache&&cache.set(obj,newObj);return newObj}(require("module$node_modules$react$index")),_propTypes=_interopRequireDefault(require("module$node_modules$prop_types$index")),_reactDom=_interopRequireDefault(require("module$node_modules$react_dom$index"))}
//# sourceMappingURL=module$node_modules$react_grid_layout$build$components$WidthProvider.js.map

==> gorilla-notes-0.5.2.jar: public/js/compiled/cljs-runtime/module$node_modules$react_grid_layout$build$components$WidthProvider.js <==
shadow$provide.module$node_modules$react_grid_layout$build$components$WidthProvider=function(global,require,module,exports){function _interopRequireDefault(obj){return obj&&obj.__esModule?obj:{default:obj}}function _getRequireWildcardCache(){if("function"!==typeof WeakMap)return null;var cache=new WeakMap;_getRequireWildcardCache=function(){return cache};return cache}function _typeof(obj$jscomp$0){"@babel/helpers - typeof";_typeof="function"===typeof Symbol&&"symbol"===typeof Symbol.iterator?function(obj){return typeof obj}:
function(obj){return obj&&"function"===typeof Symbol&&obj.constructor===Symbol&&obj!==Symbol.prototype?"symbol":typeof obj};return _typeof(obj$jscomp$0)}function _extends(){_extends=Object.assign||function(target){for(var i=1;i<arguments.length;i++){var source=arguments[i],key;for(key in source)Object.prototype.hasOwnProperty.call(source,key)&&(target[key]=source[key])}return target};return _extends.apply(this,arguments)}function _defineProperties(target,props){for(var i=0;i<props.length;i++){var descriptor=
props[i];descriptor.enumerable=descriptor.enumerable||!1;descriptor.configurable=!0;"value"in descriptor&&(descriptor.writable=!0);Object.defineProperty(target,descriptor.key,descriptor)}}function _createClass(Constructor,protoProps,staticProps){protoProps&&_defineProperties(Constructor.prototype,protoProps);staticProps&&_defineProperties(Constructor,staticProps);return Constructor}function _possibleConstructorReturn(self,call){return!call||"object"!==_typeof(call)&&"function"!==typeof call?_assertThisInitialized(self):
call}function _getPrototypeOf(o$jscomp$0){_getPrototypeOf=Object.setPrototypeOf?Object.getPrototypeOf:function(o){return o.__proto__||Object.getPrototypeOf(o)};return _getPrototypeOf(o$jscomp$0)}function _assertThisInitialized(self){if(void 0===self)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return self}function _inherits(subClass,superClass){if("function"!==typeof superClass&&null!==superClass)throw new TypeError("Super expression must either be null or a function");
subClass.prototype=Object.create(superClass&&superClass.prototype,{constructor:{value:subClass,writable:!0,configurable:!0}});superClass&&_setPrototypeOf(subClass,superClass)}function _setPrototypeOf(o$jscomp$0,p$jscomp$0){_setPrototypeOf=Object.setPrototypeOf||function(o,p){o.__proto__=p;return o};return _setPrototypeOf(o$jscomp$0,p$jscomp$0)}function _defineProperty(obj,key,value){key in obj?Object.defineProperty(obj,key,{value:value,enumerable:!0,configurable:!0,writable:!0}):obj[key]=value;return obj}
Object.defineProperty(exports,"__esModule",{value:!0});exports.default=function(ComposedComponent){var _class,_temp;return _temp=_class=function(_React$Component){function WidthProvider(){var _getPrototypeOf2;if(!(this instanceof WidthProvider))throw new TypeError("Cannot call a class as a function");for(var _len=arguments.length,args=Array(_len),_key=0;_key<_len;_key++)args[_key]=arguments[_key];var _this=_possibleConstructorReturn(this,(_getPrototypeOf2=_getPrototypeOf(WidthProvider)).call.apply(_getPrototypeOf2,
[this].concat(args)));_defineProperty(_assertThisInitialized(_this),"state",{width:1280});_defineProperty(_assertThisInitialized(_this),"mounted",!1);_defineProperty(_assertThisInitialized(_this),"onWindowResize",function(){if(_this.mounted){var node=_reactDom.default.findDOMNode(_assertThisInitialized(_this));node instanceof HTMLElement&&_this.setState({width:node.offsetWidth})}});return _this}_inherits(WidthProvider,_React$Component);_createClass(WidthProvider,[{key:"componentDidMount",value:function(){this.mounted=
!0;window.addEventListener("resize",this.onWindowResize);this.onWindowResize()}},{key:"componentWillUnmount",value:function(){this.mounted=!1;window.removeEventListener("resize",this.onWindowResize)}},{key:"render",value:function(){var _this$props=this.props,measureBeforeMount=_this$props.measureBeforeMount;var excluded=["measureBeforeMount"];if(null==_this$props)_this$props={};else{if(null==_this$props)var target={};else{target={};var sourceKeys=Object.keys(_this$props),i;for(i=0;i<sourceKeys.length;i++){var key=
sourceKeys[i];0<=excluded.indexOf(key)||(target[key]=_this$props[key])}}if(Object.getOwnPropertySymbols)for(i=Object.getOwnPropertySymbols(_this$props),key=0;key<i.length;key++)sourceKeys=i[key],0<=excluded.indexOf(sourceKeys)||Object.prototype.propertyIsEnumerable.call(_this$props,sourceKeys)&&(target[sourceKeys]=_this$props[sourceKeys]);_this$props=target}return measureBeforeMount&&!this.mounted?React.createElement("div",{className:this.props.className,style:this.props.style}):React.createElement(ComposedComponent,
_extends({},_this$props,this.state))}}]);return WidthProvider}(React.Component),_defineProperty(_class,"defaultProps",{measureBeforeMount:!1}),_defineProperty(_class,"propTypes",{measureBeforeMount:_propTypes.default.bool}),_temp};var React=function(obj){if(obj&&obj.__esModule)return obj;if(null===obj||"object"!==_typeof(obj)&&"function"!==typeof obj)return{default:obj};var cache=_getRequireWildcardCache();if(cache&&cache.has(obj))return cache.get(obj);var newObj={},hasPropertyDescriptor=Object.defineProperty&&
Object.getOwnPropertyDescriptor,key;for(key in obj)if(Object.prototype.hasOwnProperty.call(obj,key)){var desc=hasPropertyDescriptor?Object.getOwnPropertyDescriptor(obj,key):null;desc&&(desc.get||desc.set)?Object.defineProperty(newObj,key,desc):newObj[key]=obj[key]}newObj.default=obj;cache&&cache.set(obj,newObj);return newObj}(require("module$node_modules$react$index")),_propTypes=_interopRequireDefault(require("module$node_modules$prop_types$index")),_reactDom=_interopRequireDefault(require("module$node_modules$react_dom$index"))}
//# sourceMappingURL=module$node_modules$react_grid_layout$build$components$WidthProvider.js.map
